@@ -17,7 +17,7 @@
 # under the License.
 """This module contains a Google Cloud Storage operator."""
 import warnings
-from typing import Optional, Sequence, Union
+from typing import TYPE_CHECKING, Optional, Sequence, Union
 
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
@@ -25,6 +25,9 @@ from airflow.providers.google.cloud.hooks.gcs import GCSHook
 
 WILDCARD = '*'
 
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
+
 
 class GCSToGCSOperator(BaseOperator):
     """
@@ -36,21 +39,17 @@ class GCSToGCSOperator(BaseOperator):
 
     :param source_bucket: The source Google Cloud Storage bucket where the
          object is. (templated)
-    :type source_bucket: str
     :param source_object: The source name of the object to copy in the Google cloud
         storage bucket. (templated)
         You can use only one wildcard for objects (filenames) within your
         bucket. The wildcard can appear inside the object name or at the
         end of the object name. Appending a wildcard to the bucket name is
         unsupported.
-    :type source_object: str
     :param source_objects: A list of source name of the objects to copy in the Google cloud
         storage bucket. (templated)
-    :type source_objects: List[str]
     :param destination_bucket: The destination Google Cloud Storage bucket
         where the object should be. If the destination_bucket is None, it defaults
         to source_bucket. (templated)
-    :type destination_bucket: str
     :param destination_object: The destination name of the object in the
         destination Google Cloud Storage bucket. (templated)
         If a wildcard is supplied in the source_object argument, this is the
@@ -62,37 +61,27 @@ class GCSToGCSOperator(BaseOperator):
         the destination_object as e.g. ``blah/foo``, in which case the copied file
         will be named ``blah/foo/baz``.
         The same thing applies to source objects inside source_objects.
-    :type destination_object: str
     :param move_object: When move object is True, the object is moved instead
         of copied to the new location. This is the equivalent of a mv command
         as opposed to a cp command.
-    :type move_object: bool
     :param replace: Whether you want to replace existing destination files or not.
-    :type replace: bool
     :param delimiter: This is used to restrict the result to only the 'files' in a given 'folder'.
         If source_objects = ['foo/bah/'] and delimiter = '.avro', then only the 'files' in the
         folder 'foo/bah/' with '.avro' delimiter will be copied to the destination object.
-    :type delimiter: str
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param google_cloud_storage_conn_id: (Deprecated) The connection ID used to connect to Google Cloud.
         This parameter has been deprecated. You should pass the gcp_conn_id parameter instead.
-    :type google_cloud_storage_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param last_modified_time: When specified, the objects will be copied or moved,
         only if they were modified after last_modified_time.
         If tzinfo has not been set, UTC will be assumed.
-    :type last_modified_time: datetime.datetime
     :param maximum_modified_time: When specified, the objects will be copied or moved,
         only if they were modified before maximum_modified_time.
         If tzinfo has not been set, UTC will be assumed.
-    :type maximum_modified_time: datetime.datetime
     :param is_older_than: When specified, the objects will be copied if they are older
         than the specified time in seconds.
-    :type is_older_than: int
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -101,7 +90,8 @@ class GCSToGCSOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
+    :param source_object_required: Whether you want to raise an exception when the source object
+        doesn't exist. It doesn't have any effect when the source objects are folders or patterns.
 
     :Example:
 
@@ -173,7 +163,7 @@ class GCSToGCSOperator(BaseOperator):
 
     """
 
-    template_fields = (
+    template_fields: Sequence[str] = (
         'source_bucket',
         'source_object',
         'source_objects',
@@ -202,6 +192,7 @@ class GCSToGCSOperator(BaseOperator):
         maximum_modified_time=None,
         is_older_than=None,
         impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        source_object_required=False,
         **kwargs,
     ):
         super().__init__(**kwargs)
@@ -228,8 +219,9 @@ class GCSToGCSOperator(BaseOperator):
         self.maximum_modified_time = maximum_modified_time
         self.is_older_than = is_older_than
         self.impersonation_chain = impersonation_chain
+        self.source_object_required = source_object_required
 
-    def execute(self, context):
+    def execute(self, context: 'Context'):
 
         hook = GCSHook(
             gcp_conn_id=self.gcp_conn_id,
@@ -238,9 +230,8 @@ class GCSToGCSOperator(BaseOperator):
         )
         if self.source_objects and self.source_object:
             error_msg = (
-                "You can either set source_object parameter or source_objects "
-                "parameter but not both. Found source_object={} and"
-                " source_objects={}".format(self.source_object, self.source_objects)
+                f"You can either set source_object parameter or source_objects parameter but not both. "
+                f"Found source_object={self.source_object} and source_objects={self.source_objects}"
             )
             raise AirflowException(error_msg)
 
@@ -279,8 +270,6 @@ class GCSToGCSOperator(BaseOperator):
 
     def _copy_source_without_wildcard(self, hook, prefix):
         """
-
-
         For source_objects with no wildcard, this operator would first list
         all files in source_objects, using provided delimiter if any. Then copy
         files from source_objects to destination_object and rename each source
@@ -328,6 +317,11 @@ class GCSToGCSOperator(BaseOperator):
                 self._copy_single_object(
                     hook=hook, source_object=prefix, destination_object=self.destination_object
                 )
+            elif self.source_object_required:
+                msg = f"{prefix} does not exist in bucket {self.source_bucket}"
+                self.log.warning(msg)
+                raise AirflowException(msg)
+
         for source_obj in objects:
             if self.destination_object is None:
                 destination_object = source_obj
@@ -342,7 +336,7 @@ class GCSToGCSOperator(BaseOperator):
         if total_wildcards > 1:
             error_msg = (
                 "Only one wildcard '*' is allowed in source_object parameter. "
-                "Found {} in {}.".format(total_wildcards, prefix)
+                f"Found {total_wildcards} in {prefix}."
             )
 
             raise AirflowException(error_msg)
