@@ -22,7 +22,7 @@ import datetime
 import pendulum
 
 from airflow.models.dag import DAG
-from airflow.operators.dummy import DummyOperator
+from airflow.operators.empty import EmptyOperator
 
 now = pendulum.now(tz="UTC")
 now_to_the_hour = (now - datetime.timedelta(0, 0, 0, 0, 0, 3)).replace(minute=0, second=0, microsecond=0)
@@ -37,9 +37,9 @@ dag = DAG(
     catchup=False,
 )
 
-run_this_1 = DummyOperator(task_id='run_this_1', dag=dag)
-run_this_2 = DummyOperator(task_id='run_this_2', dag=dag)
+run_this_1 = EmptyOperator(task_id='run_this_1', dag=dag)
+run_this_2 = EmptyOperator(task_id='run_this_2', dag=dag)
 run_this_2.set_upstream(run_this_1)
-run_this_3 = DummyOperator(task_id='run_this_3', dag=dag)
+run_this_3 = EmptyOperator(task_id='run_this_3', dag=dag)
 run_this_3.set_upstream(run_this_2)
 # [END dag]
