@@ -157,10 +157,10 @@ class AirflowDocsBuilder:
             env['AIRFLOW_FOR_PRODUCTION'] = 'true'
         if verbose:
             console.print(
-                f"[blue]{self.package_name:60}:[/] Executing cmd: ",
+                f"[info]{self.package_name:60}:[/] Executing cmd: ",
                 " ".join(shlex.quote(c) for c in build_cmd),
             )
-            console.print(f"[blue]{self.package_name:60}:[/] The output is hidden until an error occurs.")
+            console.print(f"[info]{self.package_name:60}:[/] The output is hidden until an error occurs.")
         with open(self.log_spelling_filename, "wt") as output:
             completed_proc = run(
                 build_cmd,
@@ -189,15 +189,15 @@ class AirflowDocsBuilder:
                     warning_text += spelling_file.read()
 
             spelling_errors.extend(parse_spelling_warnings(warning_text, self._src_dir))
-            console.print(f"[blue]{self.package_name:60}:[/] [red]Finished spell-checking with errors[/]")
+            console.print(f"[info]{self.package_name:60}:[/] [red]Finished spell-checking with errors[/]")
         else:
             if spelling_errors:
                 console.print(
-                    f"[blue]{self.package_name:60}:[/] [yellow]Finished spell-checking with warnings[/]"
+                    f"[info]{self.package_name:60}:[/] [yellow]Finished spell-checking with warnings[/]"
                 )
             else:
                 console.print(
-                    f"[blue]{self.package_name:60}:[/] [green]Finished spell-checking successfully[/]"
+                    f"[info]{self.package_name:60}:[/] [green]Finished spell-checking successfully[/]"
                 )
         return spelling_errors
 
@@ -232,12 +232,12 @@ class AirflowDocsBuilder:
             env['AIRFLOW_FOR_PRODUCTION'] = 'true'
         if verbose:
             console.print(
-                f"[blue]{self.package_name:60}:[/] Executing cmd: ",
+                f"[info]{self.package_name:60}:[/] Executing cmd: ",
                 " ".join(shlex.quote(c) for c in build_cmd),
             )
         else:
             console.print(
-                f"[blue]{self.package_name:60}:[/] Running sphinx. "
+                f"[info]{self.package_name:60}:[/] Running sphinx. "
                 f"The output is hidden until an error occurs."
             )
         with open(self.log_build_filename, "wt") as output:
@@ -264,9 +264,9 @@ class AirflowDocsBuilder:
             warning_text = re.sub(r"\x1B[@-_][0-?]*[ -/]*[@-~]", "", warning_text)
             build_errors.extend(parse_sphinx_warnings(warning_text, self._src_dir))
         if build_errors:
-            console.print(f"[blue]{self.package_name:60}:[/] [red]Finished docs building with errors[/]")
+            console.print(f"[info]{self.package_name:60}:[/] [red]Finished docs building with errors[/]")
         else:
-            console.print(f"[blue]{self.package_name:60}:[/] [green]Finished docs building successfully[/]")
+            console.print(f"[info]{self.package_name:60}:[/] [green]Finished docs building successfully[/]")
         return build_errors
 
     def publish(self, override_versioned: bool):
