@@ -24,7 +24,9 @@ import traceback
 from os import path
 
 from docutils import nodes
-from docutils.parsers.rst import directives
+
+# No stub exists for docutils.parsers.rst.directives. See https://github.com/python/typeshed/issues/5755.
+from docutils.parsers.rst import directives  # type: ignore[attr-defined]
 from sphinx.directives.code import LiteralIncludeReader
 from sphinx.ext.viewcode import viewcode_anchor
 from sphinx.locale import _
